@@ -13,7 +13,16 @@ class Colour:
 	def __repr__(self):
 		return self.hex
 	def __str__(self):
-		return self.hex
+		return self.hex##
+	def __eq__(self, other):
+		if type(other) == str:
+			return self.hex == other
+		if type(other) == tuple:
+			return (self.red, self.green, self.blue) == other
+		if type(other) == list:
+			return [self.red, self.green, self.blue] == other
+		if type(other) == Colour:
+			return self.hex == other.hex
 
 def rgb_to_hex(red, green, blue):
 	decimal_hex_map = ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "a", "b", "c", "d", "e", "f"]
